"""update null workflow templates to utilize PEX

Revision ID: 86fafd27d670
Revises: e4452ab33088
Create Date: 2021-05-13 10:19:04.483390

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "86fafd27d670"
down_revision = "e4452ab33088"
branch_labels = None
depends_on = None


def upgrade():
    """
    Update null workflow templates to use PEX file for execution
    """

    submit_file_contents = """executable = null.sh
arguments = {{arguments}}

output = null.out
error = null.err
log = null.log
should_transfer_files = yes
transfer_input_files = /lustre/aoc/cluster/pipeline/$ENV(CAPO_PROFILE)/workspaces/sbin/null

queue
"""

    op.execute(
        f"UPDATE workflow_templates SET content = E'{submit_file_contents}' WHERE filename = 'null.condor'"
    )
    # Can use ./null since the PEX is copied into the HTCondor execute host's working directory
    op.execute(
        "UPDATE workflow_templates SET content = E'#!/bin/sh\n./null $*' WHERE filename = 'null.sh'"
    )


def downgrade():
    op.execute(
        "UPDATE workflow_templates SET content = E'executable = null\narguments = {{arguments}}\n"
        "error = null.err\nlog = condor.log\n\n\nqueue' WHERE filename = 'null.condor'"
    )
    op.execute(
        "UPDATE workflow_templates SET content = E'#!/bin/sh\n\nnull $*' WHERE filename = 'null.sh'"
    )
